# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TimelineRow(Component):
    """A TimelineRow component.
TimelineRow determines whether to render a bar or line chart
based on the task type and data

Keyword arguments:

- rowHeight (number; required):
    Height of each row.

- task (dict; required):
    Task data object.

    `task` is a dict with keys:

    - id (string | number; required)

    - name (string; required)

    - displayType (a value equal to: 'bar', 'line'; optional)

- yPosition (number; required):
    Y position of this row."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_gantt'
    _type = 'TimelineRow'
    @_explicitize_args
    def __init__(self, task=Component.REQUIRED, rowHeight=Component.REQUIRED, yPosition=Component.REQUIRED, getXPosition=Component.REQUIRED, getWidth=Component.REQUIRED, getColor=Component.REQUIRED, **kwargs):
        self._prop_names = ['rowHeight', 'task', 'yPosition']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['rowHeight', 'task', 'yPosition']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['rowHeight', 'task', 'yPosition']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(TimelineRow, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DashGantt(Component):
    """A DashGantt component.
DashGantt is a React component that creates an interactive Gantt chart.
It supports hierarchical data, timeline visualization, and both bar and line
chart representations. Features include horizontal scrolling, expandable rows,
and configurable styling.

@component
@param {Object} props
@param {string} [props.id] - Component identifier for Dash callbacks
@param {Array<Object>} props.data - Hierarchical data structure for the Gantt chart
@param {string} [props.title="Jobs"] - Title displayed in the left column
@param {Date|string} props.startDate - Start date for the timeline
@param {Date|string} props.endDate - End date for the timeline
@param {Date|string} [props.currentTime] - Current time for timeline indicator
@param {Object} props.timeScale - Configuration for timeline intervals
@param {number} [props.columnWidth=100] - Width of timeline columns in pixels
@param {string|number} [props.maxHeight='80vh'] - Maximum height of the component
@param {Object} [props.colorMapping] - Configuration for mapping data values to colors
@param {Array<string>} [props.tooltipFields] - Fields to display in tooltips
@param {Object} [props.expandedRowsData={}] - Current expanded state of rows
@param {Object} [props.lastExpandedRow] - Information about the last row expanded/collapsed
@param {Object} [props.styles] - Custom styles for component parts
@param {Object} [props.classNames] - Custom CSS classes
@param {Function} [props.setProps] - Dash callback property

Keyword arguments:

- id (string; optional):
    Optional ID used to identify this component in Dash callbacks.

- classNames (dict; optional):
    Optional custom CSS classes.

    `classNames` is a dict with keys:

    - container (string; optional)

    - header (string; optional)

    - jobs (string; optional)

    - timeline (string; optional)

    - taskBar (string; optional)

    - timeCell (string; optional)

    - caretButton (string; optional)

- colorMapping (dict; default {    key: 'status',    map: {        'completed': '#4CAF50',        'in_progress': '#FFA726',        'pending': '#90CAF9'    }}):
    Optional configuration for color mapping.

    `colorMapping` is a dict with keys:

    - key (string; required)

    - map (dict with strings as keys and values of type string; required)

- columnWidth (number; default 100):
    Optional width for timeline columns.

- currentTime (string; optional):
    Optional current time to show indicator.

- data (list of dicts; required):
    Required data structure defining the Gantt chart.

    `data` is a list of dicts with keys:

    - id (string | number; required)

    - name (string; required)

    - icon (string; optional)

    - children (list; optional)

    - start (string; optional)

    - end (string; optional)

    - label (string; optional)

    - status (string; optional)

    - displayType (a value equal to: 'bar', 'line'; optional)

    - dates (list of strings; optional)

    - values (list of numbers; optional)

    - color (string; optional)

- endDate (string; required):
    Required end date for the timeline.

- expandedRowsData (dict; optional):
    Current expanded state of rows, mapping row IDs to boolean
    expanded state.

- lastExpandedRow (dict; optional):
    Information about the last row that was expanded or collapsed.

    `lastExpandedRow` is a dict with keys:

    - id (string | number; optional)

    - expanded (boolean; optional)

- maxHeight (string | number; default '80vh'):
    Optional maximum height of the component.

- startDate (string; required):
    Required start date for the timeline.

- styles (dict; optional):
    Optional custom styles for component parts.

    `styles` is a dict with keys:

    - container (dict; optional)

    - header (dict; optional)

    - jobs (dict; optional)

    - timeline (dict; optional)

    - taskBar (dict; optional)

    - timeCell (dict; optional)

    - caretButton (dict; optional)

    - currentTime (dict; optional)

- timeScale (dict; default {    unit: 'hours',    value: 1,    format: 'HH:mm'}):
    Required configuration for timeline scale and formatting.

    `timeScale` is a dict with keys:

    - unit (a value equal to: 'minutes', 'hours', 'days', 'weeks', 'months'; required)

    - value (number; required)

    - format (string; required)

- title (string; default "Jobs"):
    Optional title displayed in the top left corner.

- tooltipFields (list of strings; default ['name', 'status']):
    Optional fields to display in tooltips."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_gantt'
    _type = 'DashGantt'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, data=Component.REQUIRED, title=Component.UNDEFINED, startDate=Component.REQUIRED, endDate=Component.REQUIRED, currentTime=Component.UNDEFINED, timeScale=Component.UNDEFINED, columnWidth=Component.UNDEFINED, maxHeight=Component.UNDEFINED, colorMapping=Component.UNDEFINED, tooltipFields=Component.UNDEFINED, expandedRowsData=Component.UNDEFINED, lastExpandedRow=Component.UNDEFINED, styles=Component.UNDEFINED, classNames=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'classNames', 'colorMapping', 'columnWidth', 'currentTime', 'data', 'endDate', 'expandedRowsData', 'lastExpandedRow', 'maxHeight', 'startDate', 'styles', 'timeScale', 'title', 'tooltipFields']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'classNames', 'colorMapping', 'columnWidth', 'currentTime', 'data', 'endDate', 'expandedRowsData', 'lastExpandedRow', 'maxHeight', 'startDate', 'styles', 'timeScale', 'title', 'tooltipFields']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['data', 'endDate', 'startDate']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(DashGantt, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Grid(Component):
    """A Grid component.
Grid component creates the background grid structure for the Gantt chart
including row backgrounds and time interval lines

Keyword arguments:

- columnWidth (number; required):
    Width of each column in pixels.

- currentTime (string; optional):
    Optional current time to show indicator.

- endDate (string; required):
    End date for the timeline.

- rowHeight (number; required):
    Height of each row in pixels.

- startDate (string; required):
    Start date for the timeline.

- tasks (list of dicts; required):
    Array of task objects to determine number of rows.

    `tasks` is a list of dicts with keys:

    - id (string | number; required)

- timeScale (dict; required):
    Configuration for time scale display.

    `timeScale` is a dict with keys:

    - unit (a value equal to: 'minutes', 'hours', 'days', 'weeks', 'months'; required)

    - value (number; required)

    - format (string; required)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_gantt'
    _type = 'Grid'
    @_explicitize_args
    def __init__(self, tasks=Component.REQUIRED, startDate=Component.REQUIRED, endDate=Component.REQUIRED, timeScale=Component.REQUIRED, rowHeight=Component.REQUIRED, columnWidth=Component.REQUIRED, currentTime=Component.UNDEFINED, **kwargs):
        self._prop_names = ['columnWidth', 'currentTime', 'endDate', 'rowHeight', 'startDate', 'tasks', 'timeScale']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['columnWidth', 'currentTime', 'endDate', 'rowHeight', 'startDate', 'tasks', 'timeScale']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['columnWidth', 'endDate', 'rowHeight', 'startDate', 'tasks', 'timeScale']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(Grid, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TimelineLine(Component):
    """A TimelineLine component.
TimelineLine renders a line chart representation of time series data.
Supports gradient fills and configurable styling options.

@component
@example
// Basic usage with solid fill
<TimelineLine
  data={[
    { date: '2024-02-01', value: 75 },
    { date: '2024-02-02', value: 80 },
    { date: '2024-02-03', value: 85 }
  ]}
  color="#4CAF50"
  position={20}
  width={60}
  fill={{ enabled: true, opacity: 0.3 }}
/>

@example
// Usage with gradient fill
<TimelineLine
  data={[...]}
  color="#4CAF50"
  position={20}
  width={60}
  fill={{
    enabled: true,
    gradient: {
      startOpacity: 0.4,
      endOpacity: 0.1
    }
  }}
/>

Keyword arguments:

- color (string; required):
    Primary color for the line. Should be a valid CSS color string.
    @type {string}.

- data (list of dicts; required):
    Array of data points for the line chart. Each point must have a
    date and value. @type {Array<{date: (string|Date), value:
    number}>}.

    `data` is a list of dicts with keys:

    - date (string; optional)

    - value (number; optional)

- fill (dict; default {    enabled: False,    opacity: 0.3,    gradient: {        startOpacity: 0.3,        endOpacity: 0.1    }}):
    Configuration object for fill styling. @type {Object} @property
    {boolean} [enabled=False] - Whether to enable fill @property
    {string} [color] - Fill color (defaults to line color) @property
    {number} [opacity=0.3] - Fill opacity (0-1) @property {Object}
    [gradient] - Gradient configuration @property {number}
    [gradient.startOpacity=0.3] - Start opacity for gradient @property
    {number} [gradient.endOpacity=0.1] - End opacity for gradient.

    `fill` is a dict with keys:

    - enabled (boolean; optional)

    - color (string; optional)

    - opacity (number; optional)

    - gradient (dict; optional)

        `gradient` is a dict with keys:

        - startOpacity (number; optional)

        - endOpacity (number; optional)

- position (number; required):
    Left position of the chart as a percentage of timeline width.
    @type {number}.

- width (number; required):
    Width of the chart as a percentage of timeline width. @type
    {number}."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_gantt'
    _type = 'TimelineLine'
    @_explicitize_args
    def __init__(self, data=Component.REQUIRED, color=Component.REQUIRED, position=Component.REQUIRED, width=Component.REQUIRED, fill=Component.UNDEFINED, **kwargs):
        self._prop_names = ['color', 'data', 'fill', 'position', 'width']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['color', 'data', 'fill', 'position', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['color', 'data', 'position', 'width']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(TimelineLine, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class TimelineBar(Component):
    """A TimelineBar component.
TimelineBar renders a single task bar within the Gantt chart timeline.
It handles the visual representation of a task with a defined start and end time.

@component
@param {Object} props
@param {Object} props.item - The task data object
@param {number} props.position - Left position as percentage of timeline width
@param {number} props.width - Width as percentage of timeline width
@param {string} props.color - Color code for the task bar
@param {string} [props.label] - Optional text to display inside the bar
@param {string} [props.tooltipContent] - Content to show in tooltip on hover

Keyword arguments:

- color (string; required)

- item (dict; required)

- label (string; optional)

- position (number; required)

- tooltipContent (string; optional)

- width (number; required)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_gantt'
    _type = 'TimelineBar'
    @_explicitize_args
    def __init__(self, item=Component.REQUIRED, position=Component.REQUIRED, width=Component.REQUIRED, color=Component.REQUIRED, label=Component.UNDEFINED, tooltipContent=Component.UNDEFINED, **kwargs):
        self._prop_names = ['color', 'item', 'label', 'position', 'tooltipContent', 'width']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['color', 'item', 'label', 'position', 'tooltipContent', 'width']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['color', 'item', 'position', 'width']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(TimelineBar, self).__init__(**args)



from .DashGantt import DashGantt
from .HeaderRow import HeaderRow
from .TimelineBar import TimelineBar
from .TimelineLine import TimelineLine

__all__ = [
    "DashGantt",
    "HeaderRow",
    "TimelineBar",
    "TimelineLine"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class HeaderRow(Component):
    """A HeaderRow component.
HeaderRow renders the timeline header with evenly spaced time intervals.
Handles dynamic column widths based on available space.

Keyword arguments:

- endDate (string; required):
    End date for the timeline.

- headerHeight (number; default 48):
    Height of the header in pixels.

- scrollLeft (number; required):
    Current scroll position.

- startDate (string; required):
    Start date for the timeline.

- styles (dict; optional):
    Optional custom styles for header row components.

    `styles` is a dict with keys:

    - container (dict; optional)

    - header (dict; optional)

    - jobs (dict; optional)

    - timeline (dict; optional)

    - taskBar (dict; optional)

    - timeCell (dict; optional)

    - caretButton (dict; optional)

    - currentTime (dict; optional)

- timeScale (dict; required):
    Configuration for time scale display.

    `timeScale` is a dict with keys:

    - unit (a value equal to: 'minutes', 'hours', 'days', 'weeks', 'months'; required)

    - value (number; required)

    - format (string; required)

- title (string; default "Jobs"):
    Title displayed in the left column.

- titleWidth (number; default 250):
    Width of the jobs panel."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_gantt'
    _type = 'HeaderRow'
    @_explicitize_args
    def __init__(self, startDate=Component.REQUIRED, endDate=Component.REQUIRED, timeScale=Component.REQUIRED, headerHeight=Component.UNDEFINED, scrollLeft=Component.REQUIRED, title=Component.UNDEFINED, titleWidth=Component.UNDEFINED, styles=Component.UNDEFINED, **kwargs):
        self._prop_names = ['endDate', 'headerHeight', 'scrollLeft', 'startDate', 'styles', 'timeScale', 'title', 'titleWidth']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['endDate', 'headerHeight', 'scrollLeft', 'startDate', 'styles', 'timeScale', 'title', 'titleWidth']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['endDate', 'scrollLeft', 'startDate', 'timeScale']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')

        super(HeaderRow, self).__init__(**args)
